@@ -309,7 +309,7 @@ msgstr \"\"
 \"Language-Team: LANGUAGE <LL@li.org>\\n\"
 \"MIME-Version: 1.0\\n\"
 \"Content-Type: text/plain; charset=CHARSET\\n\"
-\"Content-Transfer-Encoding: 8-bit\\n\"
+\"Content-Transfer-Encoding: 8bit\\n\"
 "
   "*Default PO file header."
   :type 'string
@@ -581,8 +581,8 @@ M-S  Ignore path          M-A  Ignore PO file      *M-L  Ignore lexicon
     (ISO_8859-9 . iso-8859-9)
     ;(ISO-8859-13 . ??)
     ;(ISO_8859-13 . ??)
-    ;(ISO-8859-15 . ??)
-    ;(ISO_8859-15 . ??)
+    (ISO-8859-15 . iso-8859-15) ; requires Emacs 21
+    (ISO_8859-15 . iso-8859-15) ; requires Emacs 21
     (KOI8-R . koi8-r)
     ;(KOI8-U . ??)
     ;(CP850 . ??)
@@ -599,18 +599,19 @@ M-S  Ignore path          M-A  Ignore PO file      *M-L  Ignore lexicon
     ;(CP1255 . ??)
     ;(CP1256 . ??)
     ;(CP1257 . ??)
-    ;(GB2312 . euc-cn)
-    ;(EUC-JP . euc-jp)
-    ;(EUC-KR . euc-kr)
+    (GB2312 . cn-gb-2312)  ; also named 'gb2312' in XEmacs 21 or Emacs 21
+                           ; also named 'euc-cn' in Emacs 20 or Emacs 21
+    (EUC-JP . euc-jp)
+    (EUC-KR . euc-kr)
     ;(EUC-TW . ??)
-    ;(BIG5 . big5)
-    ;(BIG5HKSCS . ??)
+    (BIG5 . big5)
+    ;(BIG5-HKSCS . ??)
     ;(GBK . ??)
     ;(GB18030 . ??)
-    ;(SJIS . shift_jis)
+    (SHIFT_JIS . shift_jis)
     ;(JOHAB . ??)
-    ;(TIS-620 . th-tis620)
-    ;(VISCII . viscii)
+    (TIS-620 . tis-620)    ; requires Emacs 20 or Emacs 21
+    (VISCII . viscii)      ; requires Emacs 20 or Emacs 21
     (UTF-8 . utf-8)        ; requires Mule-UCS in Emacs 20, or Emacs 21
     )
   "How to convert a GNU libc/libiconv canonical charset name as seen in
@@ -697,16 +698,15 @@ Content-Type into a Mule coding system.")
 ;;; Mode activation.
 
 (eval-and-compile
-  (if po-EMACS20
-
-      (defun po-find-file-coding-system (arg-list)
+  (if (or po-EMACS20 po-XEMACS)
+      (defun po-find-file-coding-system-guts (operation filename)
 	"Return a Mule (DECODING . ENCODING) pair, according to PO file charset.
 Called through file-coding-system-alist, before the file is visited for real."
-	(and (eq (car arg-list) 'insert-file-contents)
+	(and (eq operation 'insert-file-contents)
 	     (with-temp-buffer
 	       (let ((coding-system-for-read 'no-conversion))
 		 ;; Is 4096 enough?  FIXME: Retry as needed!
-		 (insert-file-contents (nth 1 arg-list) nil 0 4096)
+		 (insert-file-contents filename nil 0 4096)
 		 (if (re-search-forward
 		      "^\"Content-Type: text/plain;[ \t]*charset=\\([^\\]+\\)"
 		      nil t)
@@ -719,9 +719,21 @@ Called through file-coding-system-alist, before the file is visited for real."
 				 (if (memq charset-lower (coding-system-list))
 				     charset-lower
 				   'no-conversion))))
-		   '(no-conversion))))))
+		   '(no-conversion)))))))
 
-    ))
+  (if po-EMACS20
+      (defun po-find-file-coding-system (arg-list)
+	"Return a Mule (DECODING . ENCODING) pair, according to PO file charset.
+Called through file-coding-system-alist, before the file is visited for real."
+	(po-find-file-coding-system-guts (car arg-list) (car (cdr arg-list)))))
+
+  (if po-XEMACS
+      (defun po-find-file-coding-system (operation filename)
+	"Return a Mule (DECODING . ENCODING) pair, according to PO file charset.
+Called through file-coding-system-alist, before the file is visited for real."
+	(po-find-file-coding-system-guts operation filename)))
+
+ )
 
 (defvar po-mode-map nil
   "Keymap for PO mode.")
@@ -1019,7 +1031,7 @@ Position %d/%d; %d translated, %d fuzzy, %d untranslated, %d obsolete")
 		       (time (current-time))
 		       (seconds (or (car (current-time-zone time)) 0))
 		       (minutes (/ (abs seconds) 60))
-		       (zone (format "%c%02d:%02d"
+		       (zone (format "%c%02d%02d"
 				     (if (< seconds 0) ?- ?+)
 				     (/ minutes 60)
 				     (% minutes 60))))
